Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DebugMode bool
Debug mode boolean
Functions ¶
func ShouldPlaySound ¶
Function to return if we should play a sound
Types ¶
type Cpu ¶
type Cpu struct {
//Name our cpu
CpuName string
//boolean if we should render
ShouldRender bool
//Boolean for clearing the screen
ClearScreen bool
//Chip-8 has a 64 x 32 screen size, and only black our white display. So, create an array if a pizel is black (0) or white (1)
GraphicsDisplay [graphics.Width][graphics.Height]uint8
Clock *time.Ticker
// contains filtered or unexported fields
}
func DecodeOpcode ¶
Function to Decode a chip-8 opCode See here for opCodes: https://en.wikipedia.org/wiki/CHIP-8#Opcode_table Please note, Values like NNN are variables, and are supposed to be replaced with the hex value
Much thanks to https://github.com/ejholmes/chip8/blob/master/chip8.go Definitely helped in understanding the operations, and what they meant
Click to show internal directories.
Click to hide internal directories.